use std::path::Path;

use serde::Serialize;

use crate::config::Config;
use crate::error::CustomError;
use crate::intermediate::IParagraph;

use super::RenderObject;

#[derive(Debug, Serialize)]
#[serde(tag = "type")]
#[serde(rename = "paragraph")]
pub(crate) struct RenderParagraph {
    children: Vec<RenderObject>,
}

impl RenderParagraph {
    pub(crate) fn new<D: AsRef<Path>, F: AsRef<Path>>(
        config: &Config,
        output_directory: D,
        output_file: F,
        paragraph: &IParagraph,
    ) -> Result<RenderParagraph, CustomError> {
        let children = paragraph
            .children
            .iter()
            .map(|obj| RenderObject::new(config, &output_directory, &output_file, obj))
            .collect::<Result<Vec<_>, _>>()?;
        Ok(RenderParagraph { children })
    }
}
